summaryrefslogtreecommitdiff
path: root/plugins/UserInfoEx/src
diff options
context:
space:
mode:
authorGeorge Hazan <george.hazan@gmail.com>2014-11-30 21:20:14 +0000
committerGeorge Hazan <george.hazan@gmail.com>2014-11-30 21:20:14 +0000
commitd9c98bcdfca6da51a1a82dc6c0dc5996b3b6cd6d (patch)
treea6f925c63bc31e4b4dba301183cc3b429d52d816 /plugins/UserInfoEx/src
parentce2d4f19e3f810b282eb7d47d470d426ff459e1f (diff)
new sorting functions applied
git-svn-id: http://svn.miranda-ng.org/main/trunk@11180 1316c22d-e87f-b044-9b9b-93d7a3e3ba9c
Diffstat (limited to 'plugins/UserInfoEx/src')
-rw-r--r--plugins/UserInfoEx/src/Flags/svc_flags.cpp6
-rw-r--r--plugins/UserInfoEx/src/dlg_propsheet.cpp4
-rw-r--r--plugins/UserInfoEx/src/ex_import/classExImContactBase.cpp2
-rw-r--r--plugins/UserInfoEx/src/psp_about.cpp2
-rw-r--r--plugins/UserInfoEx/src/svc_constants.cpp2
-rw-r--r--plugins/UserInfoEx/src/svc_gender.cpp2
-rw-r--r--plugins/UserInfoEx/src/svc_timezone_old.cpp4
7 files changed, 11 insertions, 11 deletions
diff --git a/plugins/UserInfoEx/src/Flags/svc_flags.cpp b/plugins/UserInfoEx/src/Flags/svc_flags.cpp
index 637c6472a4..31251d0c20 100644
--- a/plugins/UserInfoEx/src/Flags/svc_flags.cpp
+++ b/plugins/UserInfoEx/src/Flags/svc_flags.cpp
@@ -170,9 +170,9 @@ static int OnContactSettingChanged(WPARAM hContact, LPARAM lParam)
/* user details update */
DBCONTACTWRITESETTING *dbcws = (DBCONTACTWRITESETTING*)lParam;
- if (!lstrcmpA(dbcws->szSetting, SET_CONTACT_COUNTRY) ||
- !lstrcmpA(dbcws->szSetting, SET_CONTACT_ORIGIN_COUNTRY) ||
- !lstrcmpA(dbcws->szSetting, SET_CONTACT_COMPANY_COUNTRY))
+ if (!mir_strcmp(dbcws->szSetting, SET_CONTACT_COUNTRY) ||
+ !mir_strcmp(dbcws->szSetting, SET_CONTACT_ORIGIN_COUNTRY) ||
+ !mir_strcmp(dbcws->szSetting, SET_CONTACT_COMPANY_COUNTRY))
{
/* Extra Image */
SetExtraImage(hContact);
diff --git a/plugins/UserInfoEx/src/dlg_propsheet.cpp b/plugins/UserInfoEx/src/dlg_propsheet.cpp
index 326d610276..304dc426ea 100644
--- a/plugins/UserInfoEx/src/dlg_propsheet.cpp
+++ b/plugins/UserInfoEx/src/dlg_propsheet.cpp
@@ -1336,13 +1336,13 @@ static INT_PTR CALLBACK DlgProc(HWND hDlg, UINT uMsg, WPARAM wParam, LPARAM lPar
break;
}
- if ( !lstrcmpA(pdbcws->szSetting, SET_CONTACT_MYHANDLE) || !lstrcmpA(pdbcws->szSetting, SET_CONTACT_NICK)) {
+ if ( !mir_strcmp(pdbcws->szSetting, SET_CONTACT_MYHANDLE) || !mir_strcmp(pdbcws->szSetting, SET_CONTACT_NICK)) {
// force the update of all propertysheetpages
DlgProc(hDlg, PSM_FORCECHANGED, NULL, NULL);
// update the windowtitle
DlgProc(hDlg, HM_SETWINDOWTITLE, NULL, lParam);
}
- else if ( !lstrcmpA(pdbcws->szModule, USERINFO) || !lstrcmpA(pdbcws->szModule, pPs->pszProto) || !lstrcmpA(pdbcws->szModule, MOD_MBIRTHDAY)) {
+ else if ( !mir_strcmp(pdbcws->szModule, USERINFO) || !mir_strcmp(pdbcws->szModule, pPs->pszProto) || !mir_strcmp(pdbcws->szModule, MOD_MBIRTHDAY)) {
// force the update of all propertysheetpages
DlgProc(hDlg, PSM_FORCECHANGED, NULL, NULL);
}
diff --git a/plugins/UserInfoEx/src/ex_import/classExImContactBase.cpp b/plugins/UserInfoEx/src/ex_import/classExImContactBase.cpp
index 2b4fd52fc3..bc44363ab4 100644
--- a/plugins/UserInfoEx/src/ex_import/classExImContactBase.cpp
+++ b/plugins/UserInfoEx/src/ex_import/classExImContactBase.cpp
@@ -489,7 +489,7 @@ BYTE CExImContactBase::isHandle(MCONTACT hContact)
// compare protocols
pszProto = DB::Contact::Proto(hContact);
- if (pszProto == NULL || (INT_PTR)pszProto == CALLSERVICE_NOTFOUND || lstrcmpA(pszProto, _pszProto))
+ if (pszProto == NULL || (INT_PTR)pszProto == CALLSERVICE_NOTFOUND || mir_strcmp(pszProto, _pszProto))
return FALSE;
// compare uids
diff --git a/plugins/UserInfoEx/src/psp_about.cpp b/plugins/UserInfoEx/src/psp_about.cpp
index aec494654a..2ee8e1fc78 100644
--- a/plugins/UserInfoEx/src/psp_about.cpp
+++ b/plugins/UserInfoEx/src/psp_about.cpp
@@ -42,7 +42,7 @@ INT_PTR CALLBACK PSPProcEdit(HWND hDlg, UINT uMsg, WPARAM wParam, LPARAM lParam,
PSGetBoldFont(hDlg, hBoldFont);
SendDlgItemMessage(hDlg, IDC_PAGETITLE, WM_SETFONT, (WPARAM)hBoldFont, 0);
- if (!lstrcmpA(pszSetting, SET_CONTACT_MYNOTES))
+ if (!mir_strcmp(pszSetting, SET_CONTACT_MYNOTES))
SetDlgItemText(hDlg, IDC_PAGETITLE, LPGENT("My notes:"));
else
SetDlgItemText(hDlg, IDC_PAGETITLE, LPGENT("About:"));
diff --git a/plugins/UserInfoEx/src/svc_constants.cpp b/plugins/UserInfoEx/src/svc_constants.cpp
index 8e97677eb6..9cd745643a 100644
--- a/plugins/UserInfoEx/src/svc_constants.cpp
+++ b/plugins/UserInfoEx/src/svc_constants.cpp
@@ -254,7 +254,7 @@ static UINT MyCountriesCount = 0;
static int __cdecl ListSortProc(const LPIDSTRLIST p1, const LPIDSTRLIST p2)
{
- return lstrcmpi(p1->ptszTranslated, p2->ptszTranslated);
+ return mir_tstrcmpi(p1->ptszTranslated, p2->ptszTranslated);
}
/**
diff --git a/plugins/UserInfoEx/src/svc_gender.cpp b/plugins/UserInfoEx/src/svc_gender.cpp
index 0582c9c82d..c440d15f3a 100644
--- a/plugins/UserInfoEx/src/svc_gender.cpp
+++ b/plugins/UserInfoEx/src/svc_gender.cpp
@@ -92,7 +92,7 @@ static int OnCListApplyIcons(MCONTACT hContact, LPARAM)
static int OnContactSettingChanged(MCONTACT hContact, DBCONTACTWRITESETTING* pdbcws)
{
- if (hContact && pdbcws && (pdbcws->value.type <= DBVT_BYTE) && !lstrcmpA(pdbcws->szSetting, SET_CONTACT_GENDER))
+ if (hContact && pdbcws && (pdbcws->value.type <= DBVT_BYTE) && !mir_strcmp(pdbcws->szSetting, SET_CONTACT_GENDER))
OnCListApplyIcons(hContact, 0);
return 0;
diff --git a/plugins/UserInfoEx/src/svc_timezone_old.cpp b/plugins/UserInfoEx/src/svc_timezone_old.cpp
index a5052f2b3d..5ebe29ec83 100644
--- a/plugins/UserInfoEx/src/svc_timezone_old.cpp
+++ b/plugins/UserInfoEx/src/svc_timezone_old.cpp
@@ -91,8 +91,8 @@ class CTzBias : public LIST<CTimeZone>
{
int result = tz2->Bias - tz1->Bias;
// DO NOT USE mir_tcsicmp here as it does only return TRUE or FALSE!!!
- // lstrcmpi takes care of umlauts e.g. Ä,Ö,....
- return (result || !tz1->ptszDisplay || !tz2->ptszDisplay) ? result : lstrcmpi(tz1->ptszDisplay, tz2->ptszDisplay);
+ // mir_tstrcmpi takes care of umlauts e.g. Ä,Ö,....
+ return (result || !tz1->ptszDisplay || !tz2->ptszDisplay) ? result : mir_tstrcmpi(tz1->ptszDisplay, tz2->ptszDisplay);
}
public:
CTzBias() : LIST<CTimeZone>(50, (FTSortFunc) CTzBias::sortFunc)